;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
; old_button = new_button
; If new_button is left blank, the button cannot be pressed.

[ReMap]
a = a
b = b
c = c
x = x
y = y
z = z
s = s

[Defaults]
Command.Time = 15
Command.Buffer.Time = 3

; These 11 Single Button and Hold Dir commands must be placed here at the top
; of the CMD, above all other commands, and in the standard order shown here,
; in order for the "Compatibly Partnered" version (9742) of the helper AI
; activation method to work with different partners in simul team mode.
; (When the partner is not compatible, then it's best to just use the regular
; version (9741) and rely on the XOR method for backup in case a human
; partner's input turns off the CPU partner's AI.)
; (Now, even if you do not intend to give your character any custom AI, it
; would still be nice if you would place the commands at the top of your CMD,
; for the sake of other characters which do use this AI activation method.
; And then, define Anim 9741 in your AIR file to indicate to other characters
; that your character is compatible.
; It may slightly increase the chances of faulty AI activation if the user is
; using characters with a poor implementation of the old humanly-impossible
; commands AI activation method when fighting against your character, but
; other than that, there's really no particular reason not to.  And you can
; change the names of the commands if you want.  For compatibility, all that
; really matters is the "command" and "time" parameters.)
;
; Another important point to make, is that if you want to add additional
; definitions for any of these basic command names, then there are limits on
; what kind of parameters you can use, in order to ensure the reliability of
; the helper method.  That is, if you redefine any of these first 11 commands,
; then you must follow these rules when doing so:
; - Don't use any command string that includes any tildes. (e.g. no "~x",
;   no "~30D")
; - In the command string, don't include any direction that isn't preceeded by
;   a slash. (e.g. no "F", no "$D")
; - Don't put any non-slashed buttons in a command string overloading one of
;   the Hold Dir command names.
; - Using a command string that includes any commas (e.g. no "a,b"), and/or
;   setting the time parameter to greater than 1, may be safe, but I wouldn't
;   risk it.
; An example of what is permissible, is redefining the "z" button like so:
;	[Command]
;	name = "z"
;	command = y+b
;	time = 1
; Other than that particular common type of redefinition, it's probably best
; to simply avoid adding definitions for these 11 command names altogether.
; And remember, this paragraph just has to do with the helper method.  You'll
; still need to make changes to the XOR code, no matter what type of overloading
; you use with the commands used by it.
;
;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |----------------------------------------------------------
; Please define Anim 74140108 in your AIR file if AND ONLY IF you place these
; 7 Hold Button commands immediately after the 11 Single Button and Hold Dir
; commands at the very top of your CMD list, as demonstrated here.
; In this version of the AI code, these commands are only used by the XOR
; method, and thus are optional.  But there remains a possibility that a
; future version of the helper method might be helped by having these
; commands placed here, and Anim 74140108 would then be used to indicate
; that a partner character has a compatible CMD.

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holdstart"
command = /s
time = 1

; Super Motions
[Command]
Name = "Messatsu Gou Hadou x"
Command = ~F, DF, D, DB, B, F, DF, D, DB, B, x
Time = 30

[Command]
Name = "Messatsu Gou Hadou x"
Command = ~F, DF, D, DB, B, F, DF, D, DB, B, ~x
Time = 30

[Command]
Name = "Messatsu Gou Hadou y"
Command = ~F, DF, D, DB, B, F, DF, D, DB, B, y
Time = 30

[Command]
Name = "Messatsu Gou Hadou y"
Command = ~F, DF, D, DB, B, F, DF, D, DB, B, ~y
Time = 30

[Command]
Name = "Messatsu Gou Hadou z"
Command = ~F, DF, D, DB, B, F, DF, D, DB, B, z
Time = 30

[Command]
Name = "Messatsu Gou Hadou z"
Command = ~F, DF, D, DB, B, F, DF, D, DB, B, ~z
Time = 30

[Command]
Name = "Messatsu Gou Rasen a"
Command = ~D, DB, B, D, DB, B, a
Time = 25

[Command]
Name = "Messatsu Gou Rasen a"
Command = ~D, DB, B, D, DB, B, ~a
Time = 25

[Command]
Name = "Messatsu Gou Rasen b"
Command = ~D, DB, B, D, DB, B, b
Time = 25

[Command]
Name = "Messatsu Gou Rasen b"
Command = ~D, DB, B, D, DB, B, ~b
Time = 25

[Command]
Name = "Messatsu Gou Rasen c"
Command = ~D, DB, B, D, DB, B, c
Time = 25

[Command]
Name = "Messatsu Gou Rasen c"
Command = ~D, DB, B, D, DB, B, ~c
Time = 25

[Command]
Name = "Messatsu Gou Rasen a"
Command = ~D, DF, F, D, DF, F, a
Time = 25

[Command]
Name = "Messatsu Gou Rasen a"
Command = ~D, DF, F, D, DF, F, ~a
Time = 25

[Command]
Name = "Messatsu Gou Rasen b"
Command = ~D, DF, F, D, DF, F, b
Time = 25

[Command]
Name = "Messatsu Gou Rasen b"
Command = ~D, DF, F, D, DF, F, ~b
Time = 25

[Command]
Name = "Messatsu Gou Rasen c"
Command = ~D, DF, F, D, DF, F, c
Time = 25

[Command]
Name = "Messatsu Gou Rasen c"
Command = ~D, DF, F, D, DF, F, ~c
Time = 25

[Command]
Name = "Messatsu Gou Hadou x"
Command = ~D, DB, B, D, DB, B, x
Time = 20

[Command]
Name = "Messatsu Gou Hadou x"
Command = ~D, DB, B, D, DB, B, ~x
Time = 20

[Command]
Name = "Messatsu Gou Hadou y"
Command = ~D, DB, B, D, DB, B, y
Time = 20

[Command]
Name = "Messatsu Gou Hadou y"
Command = ~D, DB, B, D, DB, B, ~y
Time = 20

[Command]
Name = "Messatsu Gou Hadou z"
Command = ~D, DB, B, D, DB, B, z
Time = 20

[Command]
Name = "Messatsu Gou Hadou z"
Command = ~D, DB, B, D, DB, B, ~z
Time = 20

[Command]
Name = "Tenma Gou Zankuu x"
Command = ~D, DF, F, D, DF, F, x
Time = 20

[Command]
Name = "Tenma Gou Zankuu x"
Command = ~D, DF, F, D, DF, F, ~x
Time = 20

[Command]
Name = "Tenma Gou Zankuu y"
Command = ~D, DF, F, D, DF, F, y
Time = 20

[Command]
Name = "Tenma Gou Zankuu y"
Command = ~D, DF, F, D, DF, F, ~y
Time = 20

[Command]
Name = "Tenma Gou Zankuu z"
Command = ~D, DF, F, D, DF, F, z
Time = 20

[Command]
Name = "Tenma Gou Zankuu z"
Command = ~D, DF, F, D, DF, F, ~z
Time = 20

[Command]
Name = "Messatsu Gou Shouryuu x"
Command = ~D, DF, F, D, DF, x
Time = 20

[Command]
Name = "Messatsu Gou Shouryuu x"
Command = ~D, DF, F, D, DF, ~x
Time = 20

[Command]
Name = "Messatsu Gou Shouryuu y"
Command = ~D, DF, F, D, DF, y
Time = 20

[Command]
Name = "Messatsu Gou Shouryuu y"
Command = ~D, DF, F, D, DF, ~y
Time = 20

[Command]
Name = "Messatsu Gou Shouryuu z"
Command = ~D, DF, F, D, DF, z
Time = 20

[Command]
Name = "Messatsu Gou Shouryuu z"
Command = ~D, DF, F, D, DF, ~z
Time = 20

[Command]
Name = "Shun Goku Satsu"
Command = x, x, F, a, z
Time = 30

; Special Motions
[Command]
Name = "Shakunetsu Hadou Ken x"
Command = ~F, DF, D, DB, B, x

[Command]
Name = "Shakunetsu Hadou Ken x"
Command = ~F, DF, D, DB, B, ~x

[Command]
Name = "Shakunetsu Hadou Ken y"
Command = ~F, DF, D, DB, B, y

[Command]
Name = "Shakunetsu Hadou Ken y"
Command = ~F, DF, D, DB, B, ~y

[Command]
Name = "Shakunetsu Hadou Ken z"
Command = ~F, DF, D, DB, B, z

[Command]
Name = "Shakunetsu Hadou Ken z"
Command = ~F, DF, D, DB, B, ~z

[Command]
Name = "Ashura Senkuu Fwd K"
Command = ~F, D, DF, a+b

[Command]
Name = "Ashura Senkuu Fwd K"
Command = ~F, D, DF, b+c

[Command]
Name = "Ashura Senkuu Fwd K"
Command = ~F, D, DF, a+c

[Command]
Name = "Ashura Senkuu Fwd P"
Command = ~F, D, DF, x+y

[Command]
Name = "Ashura Senkuu Fwd P"
Command = ~F, D, DF, y+z

[Command]
Name = "Ashura Senkuu Fwd P"
Command = ~F, D, DF, x+z

[Command]
Name = "Ashura Senkuu Bwd K"
Command = ~B, D, DB, a+b

[Command]
Name = "Ashura Senkuu Bwd K"
Command = ~B, D, DB, b+c

[Command]
Name = "Ashura Senkuu Bwd K"
Command = ~B, D, DB, a+c

[Command]
Name = "Ashura Senkuu Bwd P"
Command = ~B, D, DB, x+y

[Command]
Name = "Ashura Senkuu Bwd P"
Command = ~B, D, DB, x+z

[Command]
Name = "Ashura Senkuu Bwd P"
Command = ~B, D, DB, y+z

[Command]
Name = "Hyakki Shuu a"
Command = ~F, D, DF, a

[Command]
Name = "Hyakki Shuu a"
Command = ~F, D, DF, ~a

[Command]
Name = "Hyakki Shuu b"
Command = ~F, D, DF, b

[Command]
Name = "Hyakki Shuu b"
Command = ~F, D, DF, ~b

[Command]
Name = "Hyakki Shuu c"
Command = ~F, D, DF, c

[Command]
Name = "Hyakki Shuu c"
Command = ~F, D, DF, ~c

[Command]
Name = "Gou Shouryuu Ken x"
Command = ~F, D, DF, x

[Command]
Name = "Gou Shouryuu Ken x"
Command = ~F, D, DF, ~x

[Command]
Name = "Gou Shouryuu Ken y"
Command = ~F, D, DF, y

[Command]
Name = "Gou Shouryuu Ken y"
Command = ~F, D, DF, ~y

[Command]
Name = "Gou Shouryuu Ken z"
Command = ~F, D, DF, z

[Command]
Name = "Gou Shouryuu Ken z"
Command = ~F, D, DF, ~z

[Command]
Name = "Hadou Ken x"
Command = ~D, DF, F, x
Time = 10

[Command]
Name = "Hadou Ken x"
Command = ~D, DF, F, ~x
Time = 10

[Command]
Name = "Hadou Ken y"
Command = ~D, DF, F, y
Time = 10

[Command]
Name = "Hadou Ken y"
Command = ~D, DF, F, ~y
Time = 10

[Command]
Name = "Hadou Ken z"
Command = ~D, DF, F, z
Time = 10

[Command]
Name = "Hadou Ken z"
Command = ~D, DF, F, ~z
Time = 10

[Command]
Name = "Tatsumaki Zankuu Kyaku a"
Command = ~D, DB, B, a
Time = 10

[Command]
Name = "Tatsumaki Zankuu Kyaku a"
Command = ~D, DB, B, ~a
Time = 10

[Command]
Name = "Tatsumaki Zankuu Kyaku b"
Command = ~D, DB, B, b
Time = 10

[Command]
Name = "Tatsumaki Zankuu Kyaku b"
Command = ~D, DB, B, ~b
Time = 10

[Command]
Name = "Tatsumaki Zankuu Kyaku c"
Command = ~D, DB, B, c
Time = 10

[Command]
Name = "Tatsumaki Zankuu Kyaku c"
Command = ~D, DB, B, ~c
Time = 10

[Command]
Name = "Zenpou Tenshin x"
Command = ~D, DB, B, x
Time = 10

[Command]
Name = "Zenpou Tenshin x"
Command = ~D, DB, B, ~x
Time = 10

[Command]
Name = "Zenpou Tenshin y"
Command = ~D, DB, B, y
Time = 10

[Command]
Name = "Zenpou Tenshin y"
Command = ~D, DB, B, ~y
Time = 10

[Command]
Name = "Zenpou Tenshin z"
Command = ~D, DB, B, z
Time = 10

[Command]
Name = "Zenpou Tenshin z"
Command = ~D, DB, B, ~z
Time = 10

; 2/3 Button Combination
[Command]
Name 	= "Recovery Roll"
Command = a+b
Time 	= 1

[Command]
Name 	= "Recovery Roll"
Command = a+c
Time 	= 1

[Command]
Name 	= "Recovery Roll"
Command = b+c
Time 	= 1

[Command]
Name	= "recovery"
Command	= x+y
Time 	= 1

[Command]
Name	= "recovery"
Command	= x+z
Time 	= 1

[Command]
Name	= "recovery"
Command	= y+z
Time 	= 1

[Command]
Name = "2 K"
Command = a+b
Time = 1

[Command]
Name = "2 K"
Command = b+c
Time = 1

[Command]
Name = "2 K"
Command = a+c
Time = 1

[Command]
Name = "2 P"
Command = x+y
Time = 1

[Command]
Name = "2 P"
Command = y+z
Time = 1

[Command]
Name = "2 P"
Command = x+z
Time = 1

; Direction and Button
[Command]
Name = "Zero Counter"
Command	= /$F, x+a
Time = 5

[Command]
Name = "Zero Counter"
Command	= /$F, y+b
Time = 5

[Command]
Name = "Zero Counter"
Command	= /$F, z+c
Time = 5

[StateDef -1]
[State -1, Messatsu Gou Hadou x]
Type = ChangeState
TriggerAll = (Command = "Messatsu Gou Hadou x" || (Command = "Messatsu Gou Hadou y" && Power < 2000) || (Command = "Messatsu Gou Hadou z" && Power < 2000)) && Power >= 1000 && ifelse(palno > 6, 1, !NumHelper(1000)) && !NumHelper(3000) && !NumHelper(3001) && stateno != 184
Trigger1 = StateType != A && Ctrl
Trigger2 = Var(1)
Trigger3 = Var(18)
trigger4 = palno > 6 && stateno = 1000 && animelem = 4, > 0
trigger5 = palno > 6 && (stateno = [1100, 1120]) && ifelse(stateno = 1120, animelem = 2, > 0, animelem = 3, > 0) && statetype != a
trigger6 = palno > 6 && stateno = 1300 && animelem = 9, > 0
trigger7 = palno > 6 && stateno = 1500 && animelem = 11, > 0
trigger8 = palno > 6 && stateno = 1610 && animelem = 2, > 0
trigger9 = palno > 6 && (stateno = [3080, 3100]) && animelem = 11, > 0 && statetype != a
Value = 3000

[State -1, Messatsu Gou Hadou y]
Type = ChangeState
TriggerAll = (Command = "Messatsu Gou Hadou y" || (Command = "Messatsu Gou Hadou z" && Power < 3000)) && Power >= 2000 && ifelse(palno > 6, 1, !NumHelper(1000)) && !NumHelper(3000) && !NumHelper(3001) && stateno != 184
Trigger1 = StateType != A && Ctrl
Trigger2 = Var(1)
Trigger3 = Var(18)
trigger4 = palno > 6 && stateno = 1000 && animelem = 4, > 0
trigger5 = palno > 6 && (stateno = [1100, 1120]) && ifelse(stateno = 1120, animelem = 2, > 0, animelem = 3, > 0) && statetype != a
trigger6 = palno > 6 && stateno = 1300 && animelem = 9, > 0
trigger7 = palno > 6 && stateno = 1500 && animelem = 11, > 0
trigger8 = palno > 6 && stateno = 1610 && animelem = 2, > 0
trigger9 = palno > 6 && (stateno = [3080, 3100]) && animelem = 11, > 0 && statetype != a
Value = 3010

[State -1, Messatsu Gou Hadou z]
Type = ChangeState
TriggerAll = Command = "Messatsu Gou Hadou z" && Power >= 3000 && ifelse(palno > 6, 1, !NumHelper(1000)) && !NumHelper(3000) && !NumHelper(3001) && stateno != 184
Trigger1 = StateType != A && Ctrl
Trigger2 = Var(1)
Trigger3 = Var(18)
trigger4 = palno > 6 && stateno = 1000 && animelem = 4, > 0
trigger5 = palno > 6 && (stateno = [1100, 1120]) && ifelse(stateno = 1120, animelem = 2, > 0, animelem = 3, > 0) && statetype != a
trigger6 = palno > 6 && stateno = 1300 && animelem = 9, > 0
trigger7 = palno > 6 && stateno = 1500 && animelem = 11, > 0
trigger8 = palno > 6 && stateno = 1610 && animelem = 2, > 0
trigger9 = palno > 6 && (stateno = [3080, 3100]) && animelem = 11, > 0 && statetype != a
Value = 3020

[State -1, Messatsu Gou Rasen a]
Type = ChangeState
TriggerAll = (Command = "Messatsu Gou Rasen a" || (Command = "Messatsu Gou Rasen b" && Power < 2000) || (Command = "Messatsu Gou Rasen c" && Power < 2000)) && Power >= 1000 && stateno != 184
Trigger1 = Ctrl
Trigger2 = Var(1)
Trigger3 = Var(18)
trigger4 = palno > 6 && stateno = 1005 && animelem = 3, > 0
trigger5 = palno > 6 && (stateno = [1100, 1120]) && ifelse(stateno = 1120, animelem = 2, > 0, animelem = 3, > 0)
trigger6 = palno > 6 && stateno = 1300 && animelem = 9, > 0
trigger7 = palno > 6 && (stateno = [1400, 1420]) && animelem = 2, > 0
trigger8 = palno > 6 && stateno = 1610 && animelem = 2, > 0
trigger9 = palno > 6 && (stateno = [3000, 3020]) && animelem = 18, > 0
trigger10 = palno > 6 && (stateno = [3050, 3070]) && ifelse(stateno = 3050, animelem = 4, > 0, ifelse(stateno = 3060, animelem = 6, > 0, animelem = 7, > 0))
trigger11 = palno > 6 && (stateno = [3080, 3100]) && animelem = 11, > 0
Value = ifelse(statetype = a, 3191, 3190) + (Var(24) := 0)

[State -1, Messatsu Gou Rasen b]
Type = ChangeState
TriggerAll = (Command = "Messatsu Gou Rasen b" || (Command = "Messatsu Gou Rasen c" && Power < 3000)) && Power >= 2000 && stateno != 184
Trigger1 = Ctrl
Trigger2 = Var(1)
Trigger3 = Var(18)
trigger4 = palno > 6 && stateno = 1005 && animelem = 3, > 0
trigger5 = palno > 6 && (stateno = [1100, 1120]) && ifelse(stateno = 1120, animelem = 2, > 0, animelem = 3, > 0)
trigger6 = palno > 6 && stateno = 1300 && animelem = 9, > 0
trigger7 = palno > 6 && (stateno = [1400, 1420]) && animelem = 2, > 0
trigger8 = palno > 6 && stateno = 1610 && animelem = 2, > 0
trigger9 = palno > 6 && (stateno = [3000, 3020]) && animelem = 18, > 0
trigger10 = palno > 6 && (stateno = [3050, 3070]) && ifelse(stateno = 3050, animelem = 4, > 0, ifelse(stateno = 3060, animelem = 6, > 0, animelem = 7, > 0))
trigger11 = palno > 6 && (stateno = [3080, 3100]) && animelem = 11, > 0
Value = ifelse(statetype = a, 3191, 3195) + (Var(24) := 1) * 0

[State -1, Messatsu Gou Rasen c]
Type = ChangeState
TriggerAll = Command = "Messatsu Gou Rasen c" && Power >= 3000 && stateno != 184
Trigger1 = Ctrl
Trigger2 = Var(1)
Trigger3 = Var(18)
trigger4 = palno > 6 && stateno = 1005 && animelem = 3, > 0
trigger5 = palno > 6 && (stateno = [1100, 1120]) && ifelse(stateno = 1120, animelem = 2, > 0, animelem = 3, > 0)
trigger6 = palno > 6 && stateno = 1300 && animelem = 9, > 0
trigger7 = palno > 6 && (stateno = [1400, 1420]) && animelem = 2, > 0
trigger8 = palno > 6 && stateno = 1610 && animelem = 2, > 0
trigger9 = palno > 6 && (stateno = [3000, 3020]) && animelem = 18, > 0
trigger10 = palno > 6 && (stateno = [3050, 3070]) && ifelse(stateno = 3050, animelem = 4, > 0, ifelse(stateno = 3060, animelem = 6, > 0, animelem = 7, > 0))
trigger11 = palno > 6 && (stateno = [3080, 3100]) && animelem = 11, > 0
Value = ifelse(statetype = a, 3191, 3200) + (Var(24) := 2) * 0

[State -1, Tenma Gou Zankuu x]
Type = ChangeState
TriggerAll = (Command = "Tenma Gou Zankuu x" || (Command = "Tenma Gou Zankuu y" && Power < 2000) || (Command = "Tenma Gou Zankuu z" && Power < 2000)) && Power >= 1000 && ifelse(palno > 6, 1, !NumHelper(1000)) && !NumHelper(3000) && !NumHelper(3001)
Trigger1 = StateType = A && Ctrl
trigger2 = palno > 6 && stateno = 1005
trigger3 = palno > 6 && (stateno = [1100, 1120]) && ifelse(stateno = 1120, animelem = 2, > 0, animelem = 3, > 0) && statetype = a
trigger4 = palno > 6 && (stateno = [1400, 1420]) && animelem = 2, > 0
trigger5 = palno > 6 && (stateno = [3080, 3100]) && animelem = 11, > 0 && statetype = a
trigger6 = palno > 6 && (stateno = [3190, 3200]) && ifelse(stateno = 3191, animelem = 2, > 0, animelem = 6, > 0)
Value = 3050

[State -1, Tenma Gou Zankuu y]
Type = ChangeState
TriggerAll = (Command = "Tenma Gou Zankuu y" || (Command = "Tenma Gou Zankuu z" && Power < 3000)) && Power >= 2000 && ifelse(palno > 6, 1, !NumHelper(1000)) && !NumHelper(3000) && !NumHelper(3001)
Trigger1 = StateType = A && Ctrl
trigger2 = palno > 6 && stateno = 1005 && animelem = 3, > 0
trigger3 = palno > 6 && (stateno = [1100, 1120]) && ifelse(stateno = 1120, animelem = 2, > 0, animelem = 3, > 0) && statetype = a
trigger4 = palno > 6 && (stateno = [1400, 1420]) && animelem = 2, > 0
trigger5 = palno > 6 && (stateno = [3080, 3100]) && animelem = 11, > 0 && statetype = a
trigger6 = palno > 6 && (stateno = [3190, 3200]) && ifelse(stateno = 3191, animelem = 2, > 0, animelem = 6, > 0)
Value = 3060

[State -1, Tenma Gou Zankuu z]
Type = ChangeState
TriggerAll = Command = "Tenma Gou Zankuu z" && Power >= 3000 && ifelse(palno > 6, 1, !NumHelper(1000)) && !NumHelper(3000) && !NumHelper(3001)
Trigger1 = StateType = A && Ctrl
trigger2 = palno > 6 && stateno = 1005 && animelem = 3, > 0
trigger3 = palno > 6 && (stateno = [1100, 1120]) && ifelse(stateno = 1120, animelem = 2, > 0, animelem = 3, > 0) && statetype = a
trigger4 = palno > 6 && (stateno = [1400, 1420]) && animelem = 2, > 0
trigger5 = palno > 6 && (stateno = [3080, 3100]) && animelem = 11, > 0 && statetype = a
trigger6 = palno > 6 && (stateno = [3190, 3200]) && ifelse(stateno = 3191, animelem = 2, > 0, animelem = 6, > 0)
Value = 3070

[State -1, Messatsu Gou Shouryuu x]
Type = ChangeState
TriggerAll = Power >= 1000 && (Command = "Messatsu Gou Shouryuu x" || (Command = "Messatsu Gou Shouryuu y" && Power < 2000) || (Command = "Messatsu Gou Shouryuu z" && Power < 2000)) && stateno != 184
Trigger1 = StateType != A && Ctrl
Trigger2 = Var(1)
Trigger3 = Var(18)
trigger4 = palno > 6 && (stateno = [1100, 1120]) && ifelse(stateno = 1120, animelem = 2, > 0, animelem = 3, > 0) && statetype != a
trigger5 = palno > 6 && stateno = 1300 && animelem = 9, > 0
trigger6 = palno > 6 && stateno = 1610 && animelem = 2, > 0
trigger7 = palno > 6 && (stateno = [3000, 3020]) && animelem = 18, > 0
Value = 3080

[State -1, Messatsu Gou Shouryuu y]
Type = ChangeState
TriggerAll = (Command = "Messatsu Gou Shouryuu y" || (Command = "Messatsu Gou Shouryuu z" && Power < 3000)) && Power >= 2000 && stateno != 184
Trigger1 = StateType != A && Ctrl
Trigger2 = Var(1)
Trigger3 = Var(18)
trigger4 = palno > 6 && (stateno = [1100, 1120]) && ifelse(stateno = 1120, animelem = 2, > 0, animelem = 3, > 0) && statetype != a
trigger5 = palno > 6 && stateno = 1300 && animelem = 9, > 0
trigger6 = palno > 6 && stateno = 1610 && animelem = 2, > 0
trigger7 = palno > 6 && (stateno = [3000, 3020]) && animelem = 18, > 0
Value = 3090

[State -1, Messatsu Gou Shouryuu z]
Type = ChangeState
TriggerAll = Command = "Messatsu Gou Shouryuu z" && Power >= 3000 && stateno != 184
Trigger1 = StateType != A && Ctrl
Trigger2 = Var(1)
Trigger3 = Var(18)
trigger4 = palno > 6 && (stateno = [1100, 1120]) && ifelse(stateno = 1120, animelem = 2, > 0, animelem = 3, > 0) && statetype != a
trigger5 = palno > 6 && stateno = 1300 && animelem = 9, > 0
trigger6 = palno > 6 && stateno = 1610 && animelem = 2, > 0
trigger7 = palno > 6 && (stateno = [3000, 3020]) && animelem = 18, > 0
Value = 3100

[State -1, Shun Goku Satsu]
Type = ChangeState
TriggerAll = Command = "Shun Goku Satsu" && Power >= 3000 && stateno != 184
Trigger1 = StateType != A && Ctrl
Trigger2 = Var(1)
Trigger3 = Var(19)
trigger4 = palno > 6 && stateno = 1000 && animelem = 4, > 0
trigger5 = palno > 6 && (stateno = [1100, 1120]) && ifelse(stateno = 1120, animelem = 2, > 0, animelem = 3, > 0) && statetype != a
trigger6 = palno > 6 && stateno = 1300 && animelem = 9, > 0
trigger7 = palno > 6 && stateno = 1500 && animelem = 11, > 0
trigger8 = palno > 6 && stateno = 1610 && animelem = 2, > 0
Value = 3150

[State -1, Shakunetsu Hadou Ken]
Type = ChangeState
TriggerAll = (Command = "Shakunetsu Hadou Ken x" || Command = "Shakunetsu Hadou Ken y" || Command = "Shakunetsu Hadou Ken z") && !NumHelper(1000) && !NumHelper(3000) && !NumHelper(3001) && stateno != 184
Trigger1 = StateType != A && Ctrl
Trigger2 = Var(1)
Trigger3 = Var(18)
trigger4 = palno > 6 && (stateno = [1100, 1120]) && ifelse(stateno = 1120, animelem = 2, > 0, animelem = 3, > 0) && statetype != a
trigger5 = palno > 6 && stateno = 1610 && animelem = 2, > 0
Value = 1500 + (Var(24) := IfElse(Command = "Shakunetsu Hadou Ken x", 1500, IfElse(Command = "Shakunetsu Hadou Ken y", 1510, 1520))) * 0

[State -1, Ashura Senkuu]
Type = ChangeState
TriggerAll = (Command = "Ashura Senkuu Fwd K" || Command = "Ashura Senkuu Bwd K" || Command = "Ashura Senkuu Fwd P" || Command = "Ashura Senkuu Bwd P") && stateno != 184
Trigger1 = StateType != A && Ctrl
Trigger2 = Var(1)
Trigger3 = Var(18)
trigger4 = palno > 6 && (stateno = [1100, 1120]) && ifelse(stateno = 1120, animelem = 2, > 0, animelem = 3, > 0) && statetype != a
trigger5 = palno > 6 && stateno = 1610 && animelem = 2, > 0
Value = 1300 + ((Var(23) := IfElse(Command = "Ashura Senkuu Bwd K" || Command = "Ashura Senkuu Bwd P", -1, 1)) + (Var(12) := IfElse(Command = "Ashura Senkuu Fwd K" || Command = "Ashura Senkuu Bwd K" , 1300, 1305))) * 0

[State -1, Hyakki Shuu]
Type = ChangeState
TriggerAll = (Command = "Hyakki Shuu a" || Command = "Hyakki Shuu b" || Command = "Hyakki Shuu c") && stateno != 184
Trigger1 = StateType != A && Ctrl
Trigger2 = Var(1)
Trigger3 = Var(18)
trigger4 = palno > 6 && (stateno = [1100, 1120]) && ifelse(stateno = 1120, animelem = 2, > 0, animelem = 3, > 0) && statetype != a
Value = 1600 + (Var(24) := IfElse(Command = "Hyakki Shuu a", 0, IfElse(Command = "Hyakki Shuu b", 1, 2))) * 0

[State -1, Gou Shouryuu Ken]
Type = ChangeState
TriggerAll = (Command = "Gou Shouryuu Ken x" || Command = "Gou Shouryuu Ken y" || Command = "Gou Shouryuu Ken z") && stateno != 184
Trigger1 = StateType != A && Ctrl
Trigger2 = Var(1)
Trigger3 = Var(18)
trigger4 = palno > 6 && stateno = 1610 && animelem = 2, > 0
Value = IfElse(Command = "Gou Shouryuu Ken x", 1100, IfElse(Command = "Gou Shouryuu Ken y", 1110, 1120))

[State -1, Hadou Ken]
Type = ChangeState
TriggerAll = (Command = "Hadou Ken x" || Command = "Hadou Ken y" || Command = "Hadou Ken z") && !NumHelper(1000) && !NumHelper(3000) && !NumHelper(3001) && stateno != 184
Trigger1 = Ctrl && IfElse((ProjGuarded(6100) = 1), 7005, 7003)
Trigger2 = Var(1)
Trigger3 = Var(18)
trigger4 = palno > 6 && (stateno = [1100, 1120]) && ifelse(stateno = 1120, animelem = 2, > 0, animelem = 3, > 0)
trigger5 = palno > 6 && (stateno = [1400, 1420]) && animelem = 2, > 0
trigger6 = palno > 6 && stateno = 1610 && animelem = 2, > 0
Value = IfElse(StateType = A, 1005 + (Var(24) := IfElse(Command = "Hadou Ken x", 1000, IfElse(Command = "Hadou Ken y", 1001, 1002))) * 0, 1000)

[State -1, Tatsumaki Zankuu Kyaku]
Type = ChangeState
TriggerAll = (Command = "Tatsumaki Zankuu Kyaku a" || Command = "Tatsumaki Zankuu Kyaku b" || Command = "Tatsumaki Zankuu Kyaku c") && stateno != 184
Trigger1 = Ctrl
Trigger2 = Var(1)
Trigger3 = Var(18)
trigger4 = palno > 6 && (stateno = [1100, 1120]) && ifelse(stateno = 1120, animelem = 2, > 0, animelem = 3, > 0)
trigger5 = palno > 6 && stateno = 1610 && animelem = 2, > 0
Value = IfElse(StateType = A, 1405, Var(24) := IfElse(Command = "Tatsumaki Zankuu Kyaku a", 1400, IfElse(Command = "Tatsumaki Zankuu Kyaku b", 1410, 1420)))

[State -1, Zenpou Tenshin]
Type = ChangeState
TriggerAll = (Command = "Zenpou Tenshin x" || Command = "Zenpou Tenshin y" || Command = "Zenpou Tenshin z") && stateno != 184
Trigger1 = StateType != A && Ctrl
Trigger2 = Var(1)
Value = 1200
Anim = IfElse(Command = "Zenpou Tenshin x", 1200, IfElse(Command = "Zenpou Tenshin y", 1210, 1220))

[State -1, Ground Throws]
Type = ChangeState
TriggerAll = ((Command = "holdfwd" || Command = "holdback") && (Command = "2 P" || Command = "2 K")) && stateno != 184
Trigger1 = StateType = S && Ctrl
Trigger2 = Var(1)
Value = IfElse(Command = "2 P", 800 + (Var(24) := IfElse(Command = "holdfwd", 1, 0)) * 0, 850)

[State -1, Jigoku-guruma]
Type = ChangeState
TriggerAll = (Command = "holdfwd" || Command = "holdback") && Command = "2 K"
Trigger1 = StateType = A && Ctrl
Trigger2 = Var(1)
Value = 900 + (Var(24) := IfElse(Anim = 42, 1, -1)) * 0

[State -1, Zero Counter]
Type = ChangeState
TriggerAll = Command = "Zero Counter" && Power >= 1000
Trigger1 = StateNo = 150 || StateNo = 152
Value = 1140
IgnoreHitPause = 1

[State -1, Standing Jab]
Type = ChangeState
TriggerAll = Command = "x" && Command != "holddown" && stateno != 184
Trigger1 = StateType = S && Ctrl
Trigger2 = Var(1)
trigger3 = stateno = 200 && animelem = 2, > 0
Trigger4 = stateno = 400 && AnimElem = 2, > 0
Trigger5 = StateNo = 430 && AnimElem = 2, > 0
Value = 200

[State -1, Standing Strong]
Type = ChangeState
TriggerAll = Command = "y" && Command != "holddown" && stateno != 184
Trigger1 = StateType = S && Ctrl
Trigger2 = Var(1)
Value = IfElse(Command = "holdfwd", 340, IfElse(P2BodyDist X > ceil(const(size.xscale) * 35), 210, 300))

[State -1, Standing Fierce]
Type = ChangeState
TriggerAll = Command = "z" && Command != "holddown" && stateno != 184
Trigger1 = StateType = S && Ctrl
Trigger2 = Var(1)
Value = IfElse(P2BodyDist X > ceil(const(size.xscale) * 35), 220, 310)

[State -1, Standing Short]
Type = ChangeState
TriggerAll = Command = "a" && Command != "holddown" && stateno != 184
Trigger1 = StateType = S && Ctrl
Trigger2 = Var(1)
Trigger3 = StateNo = 200 && AnimElem = 2, > 0
Trigger4 = StateNo = 400 && AnimElem = 2, > 0
Trigger5 = StateNo = 430 && AnimElem = 2, > 0
Value = 230

[State -1, Standing Forward]
Type = ChangeState
TriggerAll = Command = "b" && Command != "holddown" && stateno != 184
Trigger1 = StateType = S && Ctrl
Trigger2 = Var(1)
Value = IfElse(Command = "holdfwd", 350, IfElse(P2BodyDist X > ceil(const(size.xscale) * 30), 240, 320))

[State -1, Standing Roundhouse]
Type = ChangeState
TriggerAll = Command = "c" && Command != "holddown" && stateno != 184
Trigger1 = StateType = S && Ctrl
Trigger2 = Var(1)
Value = IfElse(P2BodyDist X > ceil(const(size.xscale) * 25), 250, 330)

[State -1, Taunt]
Type = ChangeState
TriggerAll = Command = "start" && !Var(11) && stateno != 184
Trigger1 = StateType != A && Ctrl
Trigger2 = Var(1)
Trigger3 = stateNo = 200
Trigger4 = StateNo = 230
Trigger5 = (StateNo = [300, 310])
Trigger6 = StateNo = 400
Trigger7 = StateNo = 410
Trigger8 = StateNo = 420
Trigger9 = StateNo = 430
Trigger10 = StateNo = 440
Value = 195

[State -1, Crouching Jab]
Type = ChangeState
TriggerAll = Command = "x" && Command = "holddown"
Trigger1 = StateType = C && Ctrl
Trigger2 = Var(1)
Trigger3 = StateNo = 200 && AnimElem = 2, > 0
Trigger4 = stateno = 400 && AnimElem = 2, > 0
Trigger5 = StateNo = 430 && AnimElem = 2, > 0
Value = 400

[State -1, Crouching Strong]
Type = ChangeState
TriggerAll = Command = "y" && Command = "holddown"
Trigger1 = StateType = C && Ctrl
Trigger2 = Var(1)
Value = 410

[State -1, Crouching Fierce]
Type = ChangeState
TriggerAll = Command = "z" && Command = "holddown"
Trigger1 = StateType = C && Ctrl
Trigger2 = Var(1)
Value = 420

[State -1, Crouching Short]
Type = ChangeState
TriggerAll = Command = "a" && Command = "holddown"
Trigger1 = StateType = C && Ctrl
Trigger2 = Var(1)
Trigger3 = StateNo = 200 && AnimElem = 2, > 0
Trigger4 = StateNo = 400 && AnimElem = 2, > 0
Trigger5 = StateNo = 430 && AnimElem = 2, > 3
Value = 430

[State -1, Crouching Forward]
Type = ChangeState
TriggerAll = Command = "b" && Command = "holddown"
Trigger1 = StateType = C && Ctrl
Trigger2 = Var(1)
Value = 440

[State -1, Crouching Roundhouse]
Type = ChangeState
TriggerAll = Command = "c" && Command = "holddown"
Trigger1 = StateType = C && Ctrl
Trigger2 = Var(1)
Value = 450

[State -1, Jumping Jab]
Type = ChangeState
TriggerAll = Command = "x"
Trigger1 = StateType = A && Ctrl
Value = 600

[State -1, Jumping Strong]
Type = ChangeState
TriggerAll = Command = "y"
Trigger1 = StateType = A && Ctrl
Value = 610

[State -1, Jumping Fierce]
Type = ChangeState
TriggerAll = Command = "z"
Trigger1 = StateType = A && Ctrl
Value = 620

[State -1, Jumping Short]
Type = ChangeState
TriggerAll = Command = "a"
Trigger1 = StateType = A && Ctrl
Value = IfElse(!Vel X, 630, 700)

[State -1, Jumping Forward]
Type = ChangeState
TriggerAll = Command = "b"
Trigger1 = StateType = A && Ctrl
Value = IfElse(!Vel X, 640, IfElse(Command = "holddown" && Vel X > 0 && Pos Y < -80, 730, 710))

[State -1, Jumping Roundhouse]
Type = ChangeState
triggerall = Command = "c"
Trigger1 = StateType = A && Ctrl
Value = IfElse(!Vel X, 650, 720)
